@@ -53,9 +53,9 @@ private:
     rcvSetType rcvSet; // using operator< of rcVec<T>
 
 public:
+	//vecSetHash() {rcvSet.max_load_factor(0.125);}
     void duplicatedMat    	(const T* x, const int* nrow, const int* ncol, int* const out, bool const byRow=true, bool const fromLast=false);
     void anyDuplicatedMat   (const T* x, const int* nrow, const int* ncol, int* const out, bool const byRow=true, bool const fromLast=false);
-    void grpDuplicatedMat   (const T* x, const int* nrow, const int* ncol, int* const out, bool const byRow=true, bool const fromLast=false);
 };
 
 template <typename T>
@@ -71,6 +71,9 @@ void vecSetHash<T>::duplicatedMat (const T* x, const int* nrow, const int* ncol,
         aRC.vecShift = aRC.len = (int)(*nrow);
         aRC.nVec = (int)(*ncol);
     }
+	// unordered_set reserve: may or may not change bucket_count & rehashing
+	rcvSet.reserve((typename rcvSetType::size_type)aRC.nVec); 
+	
     // set insert: if not previously inserted, the .second of returned pair is true; otherwise false. the .first is an iterator for the (previously) inserted element, which is not used. 
     if (fromLast) {
         aRC.x=const_cast<T*>(x) + ( byRow ? (*nrow)-1 : ((*ncol)-1)*(*nrow) ); 
@@ -98,7 +101,9 @@ void vecSetHash<T>::anyDuplicatedMat (const T* x, const int* nrow, const int* nc
         aRC.vecShift = aRC.len = (int)(*nrow);
         aRC.nVec = (int)(*ncol);
     }
-    
+   	// unordered_set reserve: may or may not change bucket_count & rehashing
+	rcvSet.reserve((typename rcvSetType::size_type)aRC.nVec); 
+
     out[0] = 0; // result when no duplicates are found
     // set insert: if not previously inserted, the .second of returned pair is true; otherwise false. the .first is an iterator for the (previously) inserted element, which is not used. 
     if (fromLast) {
@@ -146,6 +151,9 @@ int vecMapHash<T>::grpDuplicatedMat (const T* x, const int* nrow, const int* nco
         aRC.vecShift = aRC.len = (int)(*nrow);
         aRC.nVec = (int)(*ncol);
     }
+	// unordered_map reserve: may or may not change bucket_count & rehashing
+	rcvMap.reserve((typename rcvMapType::size_type)aRC.nVec); 
+
     int grpId = 1;
     // map insert: if not previously inserted, the .second of returned pair is true; otherwise false. the .first is an iterator for the (previously) inserted element. 
     if (fromLast) {
